==> YukkuriOverwinter%200.2.4.zip: YukkuriOverwinter 0.2.4/lang/ja.js <==
var M = {};

M.get = function(code, size, key){
	if(M[code] == null)code = "BASE";
	if(M[code][size] == null)size = "L";
	if(M[code][size][key] == null){
		code = "BASE";
		if(M[code][size]　== null || M[code][size][key] == null)return "";
	}
	return M[code][size][key];
};

M.BASE = {};
M.BASE.L = {};
M.BASE.L.WALK1 = "ゆっ！ゆっ！\nゆっくりすすむよっ！";
M.BASE.L.WALK2 = "ゆっくり、ゆっくりー！";
M.BASE.L.WALK3 = "かもしかのようなあんよで\nゆっくりすすむよ！";
M.BASE.L.WALK4 = "ゆっくり\nぴょんぴょんするよ！";
M.BASE.L.GET_UP1 = "ゆっくりおきるよ！";
M.BASE.L.SLEEP1 = "すーやすーや。";
M.BASE.L.SLEEP2 = "ゆぅ・・・ゆぅ・・・";
M.BASE.L.DEAD1 = "もっとゆっくりしたかった…";
M.BASE.L.EAT1 = "む～しゃむ～しゃ！\nそれなり～";
M.BASE.L.EAT2 = "はふっはふっ！\nめっちゃうま！";
M.BASE.L.EAT3 = "む～しゃむ～しゃ\nしあわせー";
M.BASE.L.UNUN1 = "すーぱうんうんたーいむ！\nはじまるよ！";
M.BASE.L.UNUN2 = "うんうんするよーー！！";
M.BASE.L.UNUN3 = "うんうんあげるから\nよろこんでたべてねっ！！";
M.BASE.L.UNUN_END1 = "すっきりー！";
M.BASE.L.SEARCH_FOOD1 = "ゆゆ？？\nたべものさんだよ！";
M.BASE.L.UNUN_SPELL1 = "うんうんくさい！";
M.BASE.L.EAT_FAILED1 = "どぼじで\nたべものさん\nないのおおおおお！？";
M.BASE.L.SAY_HELLO1 = "%name%は%name%だよ！\nゆっくりしていってね！";
M.BASE.L.SAY_HELLO2 = "ゆっくりしていってね！";
M.BASE.L.TARGETING_EAT1 = "ゆゆ？？\nたべものさん\nはっけんだよ！";
M.BASE.L.DECLARE_PLACE1 = "ここを%name%の\nゆっくりぷれいすにするよ！";
M.BASE.L.REHUNT1 = "ゆっくりほかの\nたべものさんさがすよ！";
M.BASE.L.HUNT_ESCAPE1 = "ゆ～たいりょうだよ～";
M.BASE.L.HUNT_ESCAPE2 = "たべものさん\nもってかえるよ！";
M.BASE.L.YYUYYU1 = "ゆっゆっゆっ♪";
M.BASE.L.YYUYYU2 = "ゆっくりーのひー\nまったりーのひー\nすっきりーのひー♪";
M.BASE.L.MOVE_GOTO_HOME1 = "ゆっくりおうちにかえるよ！";
M.BASE.L.HUNTING_MESSAGE1 = "%name%はかりの\nてんっさいなんだよ！";
M.BASE.L.HUNTING_MESSAGE2 = "たべものさん\nゆっくりかられてね！";
M.BASE.L.HUNTING_MESSAGE3 = "ゆ！ゆ！\nくささんゆっくりぬけてね！";
M.BASE.L.HUNTING_MESSAGE4 = "ゆっくりごはんになってね！";
M.BASE.L.HUNTING_MESSAGE5 = "ゆっくりたべものさん\nあつめるよ！";
M.BASE.L.HUNTING_MESSAGE6 = "ゆっくりかりをするよ！！";
M.BASE.L.HUNTING_MESSAGE7 = "たべものさん\nいっぱいかるよ！";
M.BASE.L.LEARN_NO_FOOD_IN_PLACE1 = "ゆー、たべものさんがないよ";
M.BASE.L.MOVE_TO_HUNTING1 = "";

M.MARISA = {};
M.MARISA.L = {};
M.MARISA.L.WALK1 = "ゆっ！ゆっ！\nゆっくりすすむよっ！";
M.MARISA.L.WALK2 = "ゆっくり、ゆっくりー！";
M.MARISA.L.WALK3 = "かもしかのようなあんよで\nゆっくりすすむのぜ！";
M.MARISA.L.WALK4 = "ゆっくり\nぴょんぴょんするのぜ！";
M.MARISA.L.GET_UP1 = "ゆっくりおきるよ！";
M.MARISA.L.SLEEP1 = "すーやすーや。";
M.MARISA.L.SLEEP2 = "ゆぅ・・・ゆぅ・・・";
M.MARISA.L.DEAD1 = "もっとゆっくりしたかった…";
M.MARISA.L.EAT1 = "む～しゃむ～しゃ！\nそれなり～";
M.MARISA.L.EAT2 = "はふっはふっ！\nめっちゃうま！";
M.MARISA.L.EAT3 = "む～しゃむ～しゃ\nしあわせー";
M.MARISA.L.UNUN1 = "すーぱうんうんたーいむ！\nはじまるよ！";
M.MARISA.L.UNUN2 = "うんうんするよーー！！";
M.MARISA.L.UNUN3 = "うんうんあげるから\nよろこんでたべてねっ！！";
M.MARISA.L.UNUN_END1 = "すっきりー！";
M.MARISA.L.SEARCH_FOOD1 = "ゆゆ？？\nたべものさん\nはっけんなのぜ！";
M.MARISA.L.UNUN_SPELL1 = "うんうんくさい！";
M.MARISA.L.EAT_FAILED1 = "どぼじで\nたべものさん\nないのおおおおお！？";
M.MARISA.L.SAY_HELLO1 = "%name%は%name%だよ！\nゆっくりしていってね！";
M.MARISA.L.SAY_HELLO2 = "ゆっくりしていってね！";
M.MARISA.L.TARGETING_EAT1 = "ゆゆ？？\nたべものさん\nはっけんなのぜ！";
M.MARISA.L.DECLARE_PLACE1 = "ここを%name%の\nゆっくりぷれいすに\nするのぜ！";
M.MARISA.L.HUNT_ESCAPE1 = "ゆー♪たいっりょうなのぜ～";
M.MARISA.L.HUNT_ESCAPE2 = "たべものさん\nもってかえるのぜ！";
M.MARISA.L.HUNTING_MESSAGE1 = "%name%はかりの\nてんっさいなのぜ！";
M.MARISA.L.HUNTING_MESSAGE2 = "たべものさん\nゆっくりかられるのぜ！";
M.MARISA.L.HUNTING_MESSAGE3 = "ゆ！ゆ！\nくささんゆっくり\nぬけるのぜ！";
M.MARISA.L.HUNTING_MESSAGE4 = "ゆっくりごはんになってね！";
M.MARISA.L.HUNTING_MESSAGE5 = "ゆっくりたべものさん\nあつめるのぜ！";
M.MARISA.L.HUNTING_MESSAGE6 = "ゆっくりかりをするのぜ！！";
M.MARISA.L.HUNTING_MESSAGE7 = "たべものさん\nいっぱいかるのぜ！";


M.MARISA.SS = {};
M.MARISA.SS.WALK1 = "ゆっ！ゆっ！\nゆっくちしゅしゅむのじぇっ！";
M.MARISA.SS.WALK2 = "ゆっくち、ゆっくちー！";
M.MARISA.SS.WALK3 = "かもしかようなあんよで\nゆっくちしゅしゅむのじぇ！";
M.MARISA.SS.WALK4 = "ゆっくち\nぴょんぴょんするのじぇ！";
M.MARISA.SS.GET_UP1 = "ゆっくちおきるよ！";
M.MARISA.SS.SLEEP1 = "すーやすーや。";
M.MARISA.SS.SLEEP2 = "ゆぅ・・・ゆぅ・・・";
M.MARISA.SS.DEAD1 = "もっとゆっくちしたかった…";
M.MARISA.SS.EAT1 = "む～ちゃむ～ちゃ！\nしょれなり～";
M.MARISA.SS.EAT2 = "はふっはふっ！\nめっちゃうま！";
M.MARISA.SS.EAT3 = "む～ちゃむ～ちゃ\nちあわせー";
M.MARISA.SS.UNUN1 = "すーぱうんうんたーいむ！\nはじまるよ！";
M.MARISA.SS.UNUN2 = "うんうんしゅるよーー！！";
M.MARISA.SS.UNUN3 = "うんうんあげるから\nよろこんでたべちぇねっ！！";
M.MARISA.SS.UNUN_END1 = "すっきりー！";
M.MARISA.SS.SEARCH_FOOD1 = "ゆゆ？？\nたべものしゃん\nはっけんなのじぇ！";
M.MARISA.SS.UNUN_SPELL1 = "うんうんくちゃい！";
M.MARISA.SS.EAT_FAILED1 = "どぼじで\nたべものしゃん\nないのおおおおお！？";
M.MARISA.SS.SAY_HELLO1 = "%name%は%name%だよ！\nゆっくちしていってね！";
M.MARISA.SS.SAY_HELLO2 = "ゆっくちしていってね！";
M.MARISA.SS.TARGETING_EAT1 = "ゆゆ？？\nたべものしゃん\nはっけんなのじぇ！";
M.MARISA.SS.DECLARE_PLACE1 = "ここを%name%の\nゆっくちぷれいすにするのじぇ！";
M.MARISA.L.HUNT_ESCAPE1 = "ゆー♪たいっりょうなのじぇ";
M.MARISA.L.HUNT_ESCAPE2 = "たべものさん\nもってかえるのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE1 = "%name%はかりの\nてんっさいなのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE2 = "たべものしゃん\nゆっくりかられるのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE3 = "ゆ！ゆ！\nくささんゆっくり\nぬけるのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE4 = "ゆっくちごはんになってね！";
M.MARISA.SS.HUNTING_MESSAGE5 = "ゆっくちたべものさん\nあつめるのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE6 = "ゆっくちかりをするのじぇ！！";
M.MARISA.SS.HUNTING_MESSAGE7 = "たべものさん\nいっぱいかるのじぇ！";


M.LABEL = {};
M.LABEL.YUKKURI = "ゆっくり";
M.LABEL.HUNGRY = "空腹";
M.LABEL.UNUN = "うんうん";
M.LABEL.SLEEP = "眠気";
M.LABEL.STRESS = "ストレス";

==> YukkuriOverwinter%200.2.5.zip: YukkuriOverwinter 0.2.5/lang/ja.js <==
var M = {};

M.get = function(code, size, key){
	if(M[code] == null)code = "BASE";
	if(M[code][size] == null)size = "L";
	if(M[code][size][key] == null){
		code = "BASE";
		if(M[code][size]　== null){
			size = "L";
		}
		if(M[code][size][key] == null)return "";
	}
	return M[code][size][key];
};

M.BASE = {};
M.BASE.L = {};
M.BASE.L.WALK1 = "ゆっ！ゆっ！\nゆっくりすすむよっ！";
M.BASE.L.WALK2 = "ゆっくり、ゆっくりー！";
M.BASE.L.WALK3 = "かもしかのようなあんよで\nゆっくりすすむよ！";
M.BASE.L.WALK4 = "ゆっくり\nぴょんぴょんするよ！";
M.BASE.L.GET_UP1 = "ゆっくりおきるよ！";
M.BASE.L.SLEEP1 = "すーやすーや。";
M.BASE.L.SLEEP2 = "ゆぅ・・・ゆぅ・・・";
M.BASE.L.DEAD1 = "もっとゆっくりしたかった…";
M.BASE.L.EAT1 = "む～しゃむ～しゃ！\nそれなり～";
M.BASE.L.EAT2 = "はふっはふっ！\nめっちゃうま！";
M.BASE.L.EAT3 = "む～しゃむ～しゃ\nしあわせー";
M.BASE.L.UNUN1 = "すーぱうんうんたーいむ！\nはじまるよ！";
M.BASE.L.UNUN2 = "うんうんするよーー！！";
M.BASE.L.UNUN3 = "うんうんあげるから\nよろこんでたべてねっ！！";
M.BASE.L.UNUN_END1 = "すっきりー！";
M.BASE.L.SEARCH_FOOD1 = "ゆゆ？？\nたべものさんだよ！";
M.BASE.L.UNUN_SPELL1 = "うんうんくさい！";
M.BASE.L.EAT_FAILED1 = "どぼじで\nたべものさん\nないのおおおおお！？";
M.BASE.L.SAY_HELLO1 = "%name%は%name%だよ！\nゆっくりしていってね！";
M.BASE.L.SAY_HELLO2 = "ゆっくりしていってね！";
M.BASE.L.TARGETING_EAT1 = "ゆゆ？？\nたべものさん\nはっけんだよ！";
M.BASE.L.DECLARE_PLACE1 = "ここを%name%の\nゆっくりぷれいすにするよ！";
M.BASE.L.REHUNT1 = "ゆっくりほかの\nたべものさんさがすよ！";
M.BASE.L.HUNT_ESCAPE1 = "ゆ～たいりょうだよ～";
M.BASE.L.HUNT_ESCAPE2 = "たべものさん\nもってかえるよ！";
M.BASE.L.YYUYYU1 = "ゆっゆっゆっ♪";
M.BASE.L.YYUYYU2 = "ゆっくりーのひー\nまったりーのひー\nすっきりーのひー♪";
M.BASE.L.MOVE_GOTO_HOME1 = "ゆっくりおうちにかえるよ！";
M.BASE.L.HUNTING_MESSAGE1 = "%name%はかりの\nてんっさいなんだよ！";
M.BASE.L.HUNTING_MESSAGE2 = "たべものさん\nゆっくりかられてね！";
M.BASE.L.HUNTING_MESSAGE3 = "ゆ！ゆ！\nくささんゆっくりぬけてね！";
M.BASE.L.HUNTING_MESSAGE4 = "ゆっくりごはんになってね！";
M.BASE.L.HUNTING_MESSAGE5 = "ゆっくりたべものさん\nあつめるよ！";
M.BASE.L.HUNTING_MESSAGE6 = "ゆっくりかりをするよ！！";
M.BASE.L.HUNTING_MESSAGE7 = "たべものさん\nいっぱいかるよ！";
M.BASE.L.LEARN_NO_FOOD_IN_PLACE1 = "ゆー、たべものさんがないよ";
M.BASE.L.MOVE_TO_HUNTING1 = "ゆっくりかりにいくよ！";
M.BASE.L.REMOVE_YUKKURI1 = "%name%はごみじゃないよ！";
M.BASE.L.LOST_HOUSE1 = "おうちが\nなくなってるううぅぅ！！";

M.MARISA = {};
M.MARISA.L = {};
M.MARISA.L.WALK1 = "ゆっ！ゆっ！\nゆっくりすすむよっ！";
M.MARISA.L.WALK2 = "ゆっくり、ゆっくりー！";
M.MARISA.L.WALK3 = "かもしかのようなあんよで\nゆっくりすすむのぜ！";
M.MARISA.L.WALK4 = "ゆっくり\nぴょんぴょんするのぜ！";
M.MARISA.L.GET_UP1 = "ゆっくりおきるよ！";
M.MARISA.L.SLEEP1 = "すーやすーや。";
M.MARISA.L.SLEEP2 = "ゆぅ・・・ゆぅ・・・";
M.MARISA.L.DEAD1 = "もっとゆっくりしたかった…";
M.MARISA.L.EAT1 = "む～しゃむ～しゃ！\nそれなり～";
M.MARISA.L.EAT2 = "はふっはふっ！\nめっちゃうま！";
M.MARISA.L.EAT3 = "む～しゃむ～しゃ\nしあわせー";
M.MARISA.L.UNUN1 = "すーぱうんうんたーいむ！\nはじまるよ！";
M.MARISA.L.UNUN2 = "うんうんするよーー！！";
M.MARISA.L.UNUN3 = "うんうんあげるから\nよろこんでたべてねっ！！";
M.MARISA.L.UNUN_END1 = "すっきりー！";
M.MARISA.L.SEARCH_FOOD1 = "ゆゆ？？\nたべものさん\nはっけんなのぜ！";
M.MARISA.L.UNUN_SPELL1 = "うんうんくさい！";
M.MARISA.L.EAT_FAILED1 = "どぼじで\nたべものさん\nないのおおおおお！？";
M.MARISA.L.SAY_HELLO1 = "%name%は%name%だよ！\nゆっくりしていってね！";
M.MARISA.L.SAY_HELLO2 = "ゆっくりしていってね！";
M.MARISA.L.TARGETING_EAT1 = "ゆゆ？？\nたべものさん\nはっけんなのぜ！";
M.MARISA.L.DECLARE_PLACE1 = "ここを%name%の\nゆっくりぷれいすに\nするのぜ！";
M.MARISA.L.HUNT_ESCAPE1 = "ゆー♪たいっりょうなのぜ～";
M.MARISA.L.HUNT_ESCAPE2 = "たべものさん\nもってかえるのぜ！";
M.MARISA.L.HUNTING_MESSAGE1 = "%name%はかりの\nてんっさいなのぜ！";
M.MARISA.L.HUNTING_MESSAGE2 = "たべものさん\nゆっくりかられるのぜ！";
M.MARISA.L.HUNTING_MESSAGE3 = "ゆ！ゆ！\nくささんゆっくり\nぬけるのぜ！";
M.MARISA.L.HUNTING_MESSAGE4 = "ゆっくりごはんになってね！";
M.MARISA.L.HUNTING_MESSAGE5 = "ゆっくりたべものさん\nあつめるのぜ！";
M.MARISA.L.HUNTING_MESSAGE6 = "ゆっくりかりをするのぜ！！";
M.MARISA.L.HUNTING_MESSAGE7 = "たべものさん\nいっぱいかるのぜ！";
M.MARISA.L.REMOVE_YUKKURI1 = "%name%はごみじゃないのぜ！";


M.MARISA.SS = {};
M.MARISA.SS.WALK1 = "ゆっ！ゆっ！\nゆっくちしゅしゅむのじぇっ！";
M.MARISA.SS.WALK2 = "ゆっくち、ゆっくちー！";
M.MARISA.SS.WALK3 = "かもしかようなあんよで\nゆっくちしゅしゅむのじぇ！";
M.MARISA.SS.WALK4 = "ゆっくち\nぴょんぴょんするのじぇ！";
M.MARISA.SS.GET_UP1 = "ゆっくちおきるよ！";
M.MARISA.SS.SLEEP1 = "すーやすーや。";
M.MARISA.SS.SLEEP2 = "ゆぅ・・・ゆぅ・・・";
M.MARISA.SS.DEAD1 = "もっとゆっくちしたかった…";
M.MARISA.SS.EAT1 = "む～ちゃむ～ちゃ！\nしょれなり～";
M.MARISA.SS.EAT2 = "はふっはふっ！\nめっちゃうま！";
M.MARISA.SS.EAT3 = "む～ちゃむ～ちゃ\nちあわせー";
M.MARISA.SS.UNUN1 = "すーぱうんうんたーいむ！\nはじまるよ！";
M.MARISA.SS.UNUN2 = "うんうんしゅるよーー！！";
M.MARISA.SS.UNUN3 = "うんうんあげるから\nよろこんでたべちぇねっ！！";
M.MARISA.SS.UNUN_END1 = "すっきりー！";
M.MARISA.SS.SEARCH_FOOD1 = "ゆゆ？？\nたべものしゃん\nはっけんなのじぇ！";
M.MARISA.SS.UNUN_SPELL1 = "うんうんくちゃい！";
M.MARISA.SS.EAT_FAILED1 = "どぼじで\nたべものしゃん\nないのおおおおお！？";
M.MARISA.SS.SAY_HELLO1 = "%name%は%name%だよ！\nゆっくちしていってね！";
M.MARISA.SS.SAY_HELLO2 = "ゆっくちしていってね！";
M.MARISA.SS.TARGETING_EAT1 = "ゆゆ？？\nたべものしゃん\nはっけんなのじぇ！";
M.MARISA.SS.DECLARE_PLACE1 = "ここを%name%の\nゆっくちぷれいすにするのじぇ！";
M.MARISA.L.HUNT_ESCAPE1 = "ゆー♪たいっりょうなのじぇ";
M.MARISA.L.HUNT_ESCAPE2 = "たべものさん\nもってかえるのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE1 = "%name%はかりの\nてんっさいなのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE2 = "たべものしゃん\nゆっくりかられるのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE3 = "ゆ！ゆ！\nくささんゆっくり\nぬけるのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE4 = "ゆっくちごはんになってね！";
M.MARISA.SS.HUNTING_MESSAGE5 = "ゆっくちたべものさん\nあつめるのじぇ！";
M.MARISA.SS.HUNTING_MESSAGE6 = "ゆっくちかりをするのじぇ！！";
M.MARISA.SS.HUNTING_MESSAGE7 = "たべものさん\nいっぱいかるのじぇ！";


M.LABEL = {};
M.LABEL.YUKKURI = "ゆっくり";
M.LABEL.HUNGRY = "空腹";
M.LABEL.UNUN = "うんうん";
M.LABEL.SLEEP = "眠気";
M.LABEL.STRESS = "ストレス";
